@@ -573,7 +573,8 @@ class OptionsManagerMixIn(object):
         self._monkeypatch_expand_default()
         try:
             optparse.generate_manpage(self.cmdline_parser, pkginfo,
-                                 section, stream=stream or sys.stdout)
+                                      section, stream=stream or sys.stdout,
+                                      level=self._maxlevel)
         finally:
             self._unmonkeypatch_expand_default()
 
@@ -1068,7 +1069,7 @@ def read_old_config(newconfig, changes, configfile):
             newconfig[optname] = newvalue
             done.add(optname)
     for optname, optdef in newconfig.options:
-        if not optname in done:
+        if optdef.get('type') and not optname in done:
             newconfig.set_option(optname, oldconfig[optname], optdict=optdef)
 
 
