@@ -1,3 +1,20 @@
+# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
+#
+# This file is part of logilab-common.
+#
+# logilab-common is free software: you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation, either version 2.1 of the License, or (at your option) any
+# later version.
+#
+# logilab-common is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
+# details.
+#
+# You should have received a copy of the GNU Lesser General Public License along
+# with logilab-common.  If not, see <http://www.gnu.org/licenses/>.
 """File and file-path manipulation utilities.
 
 :group path manipulation: first_level_directory, relative_path, is_binary,\
@@ -5,10 +22,6 @@ get_by_ext, remove_dead_links
 :group file manipulation: norm_read, norm_open, lines, stream_lines, lines,\
 write_open_mode, ensure_fs_mode, export
 :sort: path manipulation, file manipulation
-
-:copyright: 2000-2008 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
-:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
-:license: General Public License version 2 - http://www.gnu.org/licenses
 """
 __docformat__ = "restructuredtext en"
 
@@ -71,7 +84,7 @@ def is_binary(filename):
     :rtype: bool
     :return:
       true if the file is a binary file (actually if it's mime type
-      isn't begining by text/)
+      isn't beginning by text/)
     """
     try:
         return not mimetypes.guess_type(filename)[0].startswith('text')
@@ -125,7 +138,7 @@ class ProtectedFile(file):
 
     - if IOError, then create a StringIO object
 
-    - each write operation writes in this StringIO obejct
+    - each write operation writes in this StringIO object
 
     - on close()/del(), write/append the StringIO content to the file and
       do the chmod only once
@@ -162,7 +175,7 @@ class UnresolvableError(Exception):
     """
 
 def relative_path(from_file, to_file):
-    """Try to get a relative path from from `from_file` to `to_file`
+    """Try to get a relative path from `from_file` to `to_file`
     (path will be absolute if to_file is an absolute file). This function
     is useful to create link in `from_file` to `to_file`. This typical use
     case is used in this function description.
@@ -270,7 +283,7 @@ def lines(path, comments=None):
     :type comments: str or None
     :param comments:
       optional string which can be used to comment a line in the file
-      (ie lines starting with this string won't be returned)
+      (i.e. lines starting with this string won't be returned)
 
     :rtype: list
     :return:
@@ -294,7 +307,7 @@ def stream_lines(stream, comments=None):
     :type comments: str or None
     :param comments:
       optional string which can be used to comment a line in the file
-      (ie lines starting with this string won't be returned)
+      (i.e. lines starting with this string won't be returned)
 
     :rtype: list
     :return:
@@ -340,7 +353,7 @@ def export(from_dir, to_dir,
 
     :type verbose: bool
     :param verbose:
-      flag indicating wether information about exported files should be
+      flag indicating whether information about exported files should be
       printed to stderr, default to False
     """
     def make_mirror(_, directory, fnames):
@@ -375,14 +388,14 @@ def export(from_dir, to_dir,
 
 
 def remove_dead_links(directory, verbose=0):
-    """Recursivly traverse directory and remove all dead links.
+    """Recursively traverse directory and remove all dead links.
 
     :type directory: str
     :param directory: directory to cleanup
 
     :type verbose: bool
     :param verbose:
-      flag indicating wether information about deleted links should be
+      flag indicating whether information about deleted links should be
       printed to stderr, default to False
     """
     def _remove_dead_link(_, directory, fnames):
