@@ -1,10 +1,27 @@
 # -*- coding: utf-8 -*-
+# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
+#
+# This file is part of logilab-common.
+#
+# logilab-common is free software: you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation, either version 2.1 of the License, or (at your option) any
+# later version.
+#
+# logilab-common is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
+# details.
+#
+# You should have received a copy of the GNU Lesser General Public License along
+# with logilab-common.  If not, see <http://www.gnu.org/licenses/>.
 """Python modules manipulation utility functions.
 
-:author: Logilab
-:copyright: 2000-2008 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
-:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
-:license: General Public License version 2 - http://www.gnu.org/licenses
+
+
+
+
 
 :type PY_SOURCE_EXTS: tuple(str)
 :var PY_SOURCE_EXTS: list of possible python source file extension
@@ -481,11 +498,10 @@ def is_standard_module(modname, std_path=(STD_LIB_DIR,)):
       - is located on the path listed in one of the directory in `std_path`
       - is a built-in module
     """
-    modpath = modname.split('.')
-    modname = modpath[0]
+    modname = modname.split('.')[0]
     try:
-        filename = file_from_modpath(modpath)
-    except ImportError:
+        filename = file_from_modpath([modname])
+    except ImportError, ex:
         # import failed, i'm probably not so wrong by supposing it's
         # not standard...
         return 0
