@@ -1,3 +1,20 @@
+# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
+#
+# This file is part of logilab-common.
+#
+# logilab-common is free software: you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation, either version 2.1 of the License, or (at your option) any
+# later version.
+#
+# logilab-common is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
+# details.
+#
+# You should have received a copy of the GNU Lesser General Public License along
+# with logilab-common.  If not, see <http://www.gnu.org/licenses/>.
 import tempfile
 import os
 from cStringIO import StringIO
@@ -94,8 +111,7 @@ class ConfigurationTC(TestCase):
         file = tempfile.mktemp()
         stream = open(file, 'w')
         try:
-            stream.write("""# test configuration
-[Test]
+            stream.write("""[Test]
 
 dothis=no
 
@@ -130,8 +146,7 @@ diffgroup=zou
     def test_generate_config(self):
         stream = StringIO()
         self.cfg.generate_config(stream)
-        self.assertLinesEquals(stream.getvalue().strip(), """# test configuration
-[TEST]
+        self.assertLinesEquals(stream.getvalue().strip(), """[TEST]
 
 dothis=yes
 
@@ -159,8 +174,7 @@ diffgroup=pouet
         self.cfg['value'] = '    '
         stream = StringIO()
         self.cfg.generate_config(stream)
-        self.assertLinesEquals(stream.getvalue().strip(), """# test configuration
-[TEST]
+        self.assertLinesEquals(stream.getvalue().strip(), """[TEST]
 
 dothis=yes
 
@@ -284,8 +298,7 @@ options:
         read_old_config(self.cfg, changes, 'data/test.ini')
         stream = StringIO()
         self.cfg.generate_config(stream)
-        self.assertLinesEquals(stream.getvalue().strip(), """# test configuration
-[TEST]
+        self.assertLinesEquals(stream.getvalue().strip(), """[TEST]
 
 dothis=yes
 
