@@ -1,3 +1,20 @@
+# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
+#
+# This file is part of logilab-common.
+#
+# logilab-common is free software: you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation, either version 2.1 of the License, or (at your option) any
+# later version.
+#
+# logilab-common is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
+# details.
+#
+# You should have received a copy of the GNU Lesser General Public License along
+# with logilab-common.  If not, see <http://www.gnu.org/licenses/>.
 """unittest module for logilab.comon.testlib"""
 
 import unittest
@@ -201,7 +218,9 @@ class TestlibTC(TestCase):
         self.assertRaises(AssertionError, self.tc.assertTextEqual, "toto", None)
         self.assertRaises(AssertionError, self.tc.assertTextEqual, 3.12, u"toto")
         self.assertRaises(AssertionError, self.tc.assertTextEqual, None, u"toto")
-
+        self.tc.assertTextEqual('toto\ntiti', 'toto\ntiti')
+        self.tc.assertTextEqual('toto\ntiti', 'toto\n titi\n', striplines=True)
+        self.assertRaises(AssertionError, self.tc.assertTextEqual, 'toto\ntiti', 'toto\n titi\n')
         foo = join(dirname(__file__), 'data', 'foo.txt')
         spam = join(dirname(__file__), 'data', 'spam.txt')
         text1 = file(foo).read()
