@@ -1,9 +1,26 @@
+# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
+#
+# This file is part of logilab-common.
+#
+# logilab-common is free software: you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation, either version 2.1 of the License, or (at your option) any
+# later version.
+#
+# logilab-common is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
+# details.
+#
+# You should have received a copy of the GNU Lesser General Public License along
+# with logilab-common.  If not, see <http://www.gnu.org/licenses/>.
 """Some text manipulation utility functions.
 
-:author:    Logilab
-:copyright: 2003-2008 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
-:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
-:license: GNU Lesser General Public License, v2.1 - http://www.gnu.org/licenses
+
+
+
+
 
 :group text formatting: normalize_text, normalize_paragraph, pretty_match,\
 unquote, colorize_ansi
@@ -378,13 +395,13 @@ ANSI_COLORS = {
     'white'   : "37",
 }
 
-
 def _get_ansi_code(color=None, style=None):
     """return ansi escape code corresponding to color and style
 
     :type color: str or None
     :param color:
-      the color identifier (see `ANSI_COLORS` for available values)
+      the color name (see `ANSI_COLORS` for available values)
+      or the color number when 256 colors are available
 
     :type style: str or None
     :param style:
@@ -402,7 +419,11 @@ def _get_ansi_code(color=None, style=None):
         for effect in style_attrs:
             ansi_code.append(ANSI_STYLES[effect])
     if color:
-        ansi_code.append(ANSI_COLORS[color])
+        if color.isdigit():
+            ansi_code.extend(['38','5'])
+            ansi_code.append(color)
+        else:
+            ansi_code.append(ANSI_COLORS[color])
     if ansi_code:
         return ANSI_PREFIX + ';'.join(ansi_code) + ANSI_END
     return ''
